@@ -1,6 +1,7 @@
 from pathlib import Path
 from subprocess import check_call, check_output
 import logging
+import os
 import sys
 
 try:
@@ -11,7 +12,7 @@ except ImportError as e:
     raise ImportError(err) from e
 import tomli
 
-from .consts import CMEEL_PREFIX
+from .consts import CMEEL_PREFIX, SITELIB
 from .config import cmeel_config
 from . import __version__
 
@@ -32,7 +33,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     BUILD = TEMP / "bld"
     PREFIX = TEMP / "pfx"
     INSTALL = PREFIX / CMEEL_PREFIX
-    TAG = str(next(sys_tags()))
+    TAG = os.environ.get("_PYTHON_HOST_PLATFORM", str(next(sys_tags())))
 
     logging.info("load conf from pyproject.toml")
     with open("pyproject.toml", "rb") as f:
@@ -58,6 +59,14 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         logging.info("patching")
         check_call(["patch", "-p0", "-i", "cmeel.patch"])
 
+    # Set env
+
+    if RUN_TESTS_AFTER_INSTALL:
+        path = f"{INSTALL / SITELIB}"
+        if old := os.environ.get("PYTHONPATH", ""):
+            path += f"{os.pathsep}{old}"
+        os.environ.update(PYTHONPATH=path)
+
     # Configure
 
     logging.info("configure")
@@ -86,8 +95,8 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     logging.info("fix relocatablization")
     for f in INSTALL.rglob("*.cmake"):
         ff = INSTALL / f"{f.stem}.fix"
-        with f.open("r") as fr, fw.open("w") as fw:
-            fw.write(fr.read().replace(INSTALL, "${PACKAGE_PREFIX_DIR}"))
+        with f.open("r") as fr, ff.open("w") as fw:
+            fw.write(fr.read().replace(str(INSTALL), "${PACKAGE_PREFIX_DIR}"))
         f.unlink()
         ff.rename(f)
 
